missing_cells() extracts the missing unit-time combinations stored in an
audit object created by audit_panel().
Arguments
- x
An object created by
audit_panel().
Details
Missing cells are unit-time combinations that are implied by the full unit-by-time grid but are not present in the original data.
This function does not re-audit the original dataset. It simply extracts the missing-cell table already stored in the audit object.
Examples
audit <- audit_panel(example_panel, id = id, time = year)
missing_cells(audit)
#> # A tibble: 4 × 2
#> id year
#> <dbl> <dbl>
#> 1 1 2022
#> 2 1 2023
#> 3 2 2021
#> 4 2 2023